@@ -1,14 +1,10 @@
-/* Copyright (c) 1998 Joe Rumsey (mrogre@mediaone.net) */
+/* Copyright (c) 1995-1998 Joe Rumsey (mrogre@mediaone.net) */
 #include "copyright.h"
 /*
  * main.c for XGalaga
- * Copyright (c) 1995 Joe Rumsey
  */
-#include "copyright.h"
 #include <config.h>
 
-#define IM_A_BIG_FAT_CHEATER
-
 #include <stdio.h>
 #include <stdlib.h>
 #ifdef HAVE_SYS_TIME_H
@@ -83,6 +79,7 @@ Command line options:\n\
 -display <display>   Set your display\n\
 -mouse               Use mouse control (same as 'm' at the title screen)\n\
 -keyboard            Use keyboard control (same as 'k')\n%s\
+-level <number>      Choose starting level (>= 1)\n\
 -b                   turn buffered mode off, use this if it runs\n\
 too slowly.  Will cause flicker, maybe lots,\n\
 maybe only a little.\n\
@@ -234,8 +231,6 @@ static void init_aliens(int level)
         new_alien(level, i, &aliens[i]);
     }
 
-    printf("%d,%d", get_dir(7,1), get_duration(7,1));
-
     for(i=0;i<MAXTORPS;i++)
         torps[i].alive = 0;
 }
@@ -785,7 +780,9 @@ static void do_player()
         while(W_EventsPending()) {
             W_NextEvent(&wev);
         
-            mouseControl = 1;
+	    if(gameOver)
+	      mouseControl = 1;
+
             switch(wev.type) {
             case W_EV_KEY:
                 if(score_key(&wev))
@@ -812,7 +809,7 @@ static void do_player()
                     weapon = 0;
                     movespeed = MINSPEED;
                     ships=2;
-                    level=1;
+                    level=startLevel;  /* change made here */
                     init_aliens(level);
                     gotlemon = 0;
                     pldead = 0;
@@ -1064,6 +1061,11 @@ char  **argv;
             } else if (strcmp(argv[ac], "-nosound") == 0) {
                 playSounds = 0;
 #endif
+	/* '-level' option defined here */
+            } else if (strcmp(argv[ac], "-level") == 0 && (ac+1 < argc) 
+                       && atoi(argv[ac+1]) >= 1) {
+                startLevel = atoi(argv[ac+1]);
+                ac++;
             } else {
                 print_usage();
                 exit(0);
@@ -1091,7 +1093,7 @@ char  **argv;
     enemyTorp = getImage(I_ETORP);
     shieldImage = getImage(I_SHIELD);
 
-    level=1;
+    level=startLevel;   /* change made here */
 
     load_scores();
     init_titles();
